=======
planets
=======


.. image:: https://img.shields.io/pypi/v/planets.svg
        :target: https://pypi.python.org/pypi/planets

.. image:: https://img.shields.io/travis/michaelaye/planets.svg
        :target: https://travis-ci.org/michaelaye/planets

.. image:: https://readthedocs.org/projects/planets/badge/?version=latest
        :target: https://planets.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status

.. image:: https://pyup.io/repos/github/michaelaye/planets/shield.svg
     :target: https://pyup.io/repos/github/michaelaye/planets/
     :alt: Updates


Library to provide planetary constants


* Free software: MIT license
* Documentation: https://planets.readthedocs.io.


Features
--------

* TODO

Credits
---------

Planetary Database
~~~~~~~~~~~~~~~~~~

Modified by Paul Hayne from the "planets.py" library by Raymond T. Pierrehumbert

Last modified: June, 2017

Sources:

1. http://nssdc.gsfc.nasa.gov/planetary/factsheet/
2. Lang, K. (2012). Astrophysical data: planets and stars. Springer Science & Business Media.    

Python packaging
~~~~~~~~~~~~~~~~

This package was created with Cookiecutter_ and the forked `michaelaye/cookiecutter-pypackage-conda`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`michaelaye/cookiecutter-pypackage-conda`: https://github.com/michaelaye/cookiecutter-pypackage-conda
